DEFAULT_CONFIG = {
    "edit_button_template_name": {
        "bootstrap4": "crispy_formset_modal/bootstrap4/edit_button.html",
        "bootstrap5": "crispy_formset_modal/bootstrap5/edit_button.html",
        "bulma": "crispy_formset_modal/bulma/edit_button.html",
        "tailwind": "crispy_formset_modal/tailwind/edit_button.html",
    },
}
